# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`mongodb::client`](#mongodb--client): Class for installing a MongoDB client shell (CLI).
* [`mongodb::globals`](#mongodb--globals): Class for setting cross-class global overrides. See README.md for more details.
* [`mongodb::mongos`](#mongodb--mongos): This installs a Mongo Shard daemon. See README.md for more details.
* [`mongodb::opsmanager`](#mongodb--opsmanager): This installs Ops Manager
* [`mongodb::replset`](#mongodb--replset): Wrapper class useful for hiera based deployments
* [`mongodb::server`](#mongodb--server): This installs a MongoDB server. See README.md for more details.
* [`mongodb::shardsvr`](#mongodb--shardsvr): Wrapper class useful for hiera based deployments

#### Private Classes

* `mongodb::client::params`: mongodb client params
* `mongodb::mongos::config`: Manages mongos config
* `mongodb::mongos::install`: Manages the mongos package
* `mongodb::mongos::params`: mongos params
* `mongodb::mongos::service`: Manages the mongos service
* `mongodb::params`: mongodb params
* `mongodb::repo`: Manages the mongodb repository
* `mongodb::repo::apt`: This is a repo class for apt
* `mongodb::repo::yum`: This is a repo class for yum
* `mongodb::repo::zypper`: This is a repo class for zypper
* `mongodb::server::config`: Manages mongod config
* `mongodb::server::install`: Manages the mongod package
* `mongodb::server::service`: Manages the mongos service

### Defined types

* [`mongodb::db`](#mongodb--db): Class for creating mongodb databases and users.

### Resource types

* [`mongodb_conn_validator`](#mongodb_conn_validator): Verify that a connection can be successfully established between a node and the mongodb server.  Its primary use is as a precondition to prev
* [`mongodb_database`](#mongodb_database): Manage MongoDB databases.
* [`mongodb_replset`](#mongodb_replset): Manage a MongoDB replicaSet
* [`mongodb_shard`](#mongodb_shard): Manage a MongoDB Shard
* [`mongodb_user`](#mongodb_user): Manage a MongoDB user. This includes management of users password as well as privileges.

### Functions

* [`mongodb_password`](#mongodb_password): Get the mongodb password hash from the clear text password.

## Classes

### <a name="mongodb--client"></a>`mongodb::client`

Class for installing a MongoDB client shell (CLI).

#### Parameters

The following parameters are available in the `mongodb::client` class:

* [`ensure`](#-mongodb--client--ensure)
* [`package_name`](#-mongodb--client--package_name)

##### <a name="-mongodb--client--ensure"></a>`ensure`

Data type: `String[1]`

Desired ensure state of the package.

Default value: `$mongodb::client::params::package_ensure`

##### <a name="-mongodb--client--package_name"></a>`package_name`

Data type: `String[1]`

Name of the package to install the client from. Default is repository dependent.

Default value: `$mongodb::client::params::package_name`

### <a name="mongodb--globals"></a>`mongodb::globals`

Class for setting cross-class global overrides. See README.md for more details.

#### Parameters

The following parameters are available in the `mongodb::globals` class:

* [`server_package_name`](#-mongodb--globals--server_package_name)
* [`client_package_name`](#-mongodb--globals--client_package_name)
* [`mongod_service_manage`](#-mongodb--globals--mongod_service_manage)
* [`service_enable`](#-mongodb--globals--service_enable)
* [`service_ensure`](#-mongodb--globals--service_ensure)
* [`service_name`](#-mongodb--globals--service_name)
* [`service_provider`](#-mongodb--globals--service_provider)
* [`service_status`](#-mongodb--globals--service_status)
* [`user`](#-mongodb--globals--user)
* [`group`](#-mongodb--globals--group)
* [`ipv6`](#-mongodb--globals--ipv6)
* [`bind_ip`](#-mongodb--globals--bind_ip)
* [`version`](#-mongodb--globals--version)
* [`repo_version`](#-mongodb--globals--repo_version)
* [`manage_package_repo`](#-mongodb--globals--manage_package_repo)
* [`manage_package`](#-mongodb--globals--manage_package)
* [`repo_proxy`](#-mongodb--globals--repo_proxy)
* [`proxy_username`](#-mongodb--globals--proxy_username)
* [`proxy_password`](#-mongodb--globals--proxy_password)
* [`repo_location`](#-mongodb--globals--repo_location)
* [`use_enterprise_repo`](#-mongodb--globals--use_enterprise_repo)
* [`pidfilepath`](#-mongodb--globals--pidfilepath)
* [`pidfilemode`](#-mongodb--globals--pidfilemode)
* [`manage_pidfile`](#-mongodb--globals--manage_pidfile)

##### <a name="-mongodb--globals--server_package_name"></a>`server_package_name`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--client_package_name"></a>`client_package_name`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--mongod_service_manage"></a>`mongod_service_manage`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--service_enable"></a>`service_enable`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--service_ensure"></a>`service_ensure`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--service_name"></a>`service_name`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--service_provider"></a>`service_provider`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--service_status"></a>`service_status`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--user"></a>`user`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--group"></a>`group`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--ipv6"></a>`ipv6`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--bind_ip"></a>`bind_ip`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--version"></a>`version`

Data type: `Optional[String[1]]`

Version of mongodb to install

Default value: `undef`

##### <a name="-mongodb--globals--repo_version"></a>`repo_version`

Data type: `String[1]`

Version of mongodb repo to install

Default value: `'5.0'`

##### <a name="-mongodb--globals--manage_package_repo"></a>`manage_package_repo`

Data type: `Boolean`

If `true` configure upstream mongodb repos

Default value: `true`

##### <a name="-mongodb--globals--manage_package"></a>`manage_package`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--repo_proxy"></a>`repo_proxy`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--proxy_username"></a>`proxy_username`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--proxy_password"></a>`proxy_password`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--repo_location"></a>`repo_location`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--use_enterprise_repo"></a>`use_enterprise_repo`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--pidfilepath"></a>`pidfilepath`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--pidfilemode"></a>`pidfilemode`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--globals--manage_pidfile"></a>`manage_pidfile`

Data type: `Any`



Default value: `undef`

### <a name="mongodb--mongos"></a>`mongodb::mongos`

This installs a Mongo Shard daemon. See README.md for more details.

#### Parameters

The following parameters are available in the `mongodb::mongos` class:

* [`config`](#-mongodb--mongos--config)
* [`config_content`](#-mongodb--mongos--config_content)
* [`config_template`](#-mongodb--mongos--config_template)
* [`configdb`](#-mongodb--mongos--configdb)
* [`config_data`](#-mongodb--mongos--config_data)
* [`service_manage`](#-mongodb--mongos--service_manage)
* [`service_provider`](#-mongodb--mongos--service_provider)
* [`service_name`](#-mongodb--mongos--service_name)
* [`service_user`](#-mongodb--mongos--service_user)
* [`service_group`](#-mongodb--mongos--service_group)
* [`service_template`](#-mongodb--mongos--service_template)
* [`service_enable`](#-mongodb--mongos--service_enable)
* [`service_ensure`](#-mongodb--mongos--service_ensure)
* [`service_status`](#-mongodb--mongos--service_status)
* [`package_ensure`](#-mongodb--mongos--package_ensure)
* [`package_name`](#-mongodb--mongos--package_name)
* [`unixsocketprefix`](#-mongodb--mongos--unixsocketprefix)
* [`pidfilepath`](#-mongodb--mongos--pidfilepath)
* [`logpath`](#-mongodb--mongos--logpath)
* [`fork`](#-mongodb--mongos--fork)
* [`bind_ip`](#-mongodb--mongos--bind_ip)
* [`port`](#-mongodb--mongos--port)
* [`restart`](#-mongodb--mongos--restart)

##### <a name="-mongodb--mongos--config"></a>`config`

Data type: `Stdlib::Absolutepath`



Default value: `$mongodb::mongos::params::config`

##### <a name="-mongodb--mongos--config_content"></a>`config_content`

Data type: `Optional[String[1]]`



Default value: `$mongodb::mongos::params::config_content`

##### <a name="-mongodb--mongos--config_template"></a>`config_template`

Data type: `Optional[String[1]]`



Default value: `$mongodb::mongos::params::config_template`

##### <a name="-mongodb--mongos--configdb"></a>`configdb`

Data type: `Variant[String[1], Array[String[1]]]`



Default value: `$mongodb::mongos::params::configdb`

##### <a name="-mongodb--mongos--config_data"></a>`config_data`

Data type: `Optional[Hash]`



Default value: `$mongodb::mongos::params::config_data`

##### <a name="-mongodb--mongos--service_manage"></a>`service_manage`

Data type: `Boolean`



Default value: `$mongodb::mongos::params::service_manage`

##### <a name="-mongodb--mongos--service_provider"></a>`service_provider`

Data type: `Optional[String]`



Default value: `$mongodb::mongos::params::service_provider`

##### <a name="-mongodb--mongos--service_name"></a>`service_name`

Data type: `Optional[String]`



Default value: `$mongodb::mongos::params::service_name`

##### <a name="-mongodb--mongos--service_user"></a>`service_user`

Data type: `String`



Default value: `'mongodb'`

##### <a name="-mongodb--mongos--service_group"></a>`service_group`

Data type: `String`



Default value: `'mongodb'`

##### <a name="-mongodb--mongos--service_template"></a>`service_template`

Data type: `Optional[String[1]]`



Default value: `$mongodb::mongos::params::service_template`

##### <a name="-mongodb--mongos--service_enable"></a>`service_enable`

Data type: `Boolean`



Default value: `$mongodb::mongos::params::service_enable`

##### <a name="-mongodb--mongos--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`



Default value: `$mongodb::mongos::params::service_ensure`

##### <a name="-mongodb--mongos--service_status"></a>`service_status`

Data type: `Optional[String]`



Default value: `$mongodb::mongos::params::service_status`

##### <a name="-mongodb--mongos--package_ensure"></a>`package_ensure`

Data type: `Variant[Boolean, String]`



Default value: `$mongodb::mongos::params::package_ensure`

##### <a name="-mongodb--mongos--package_name"></a>`package_name`

Data type: `String`



Default value: `$mongodb::mongos::params::package_name`

##### <a name="-mongodb--mongos--unixsocketprefix"></a>`unixsocketprefix`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `$mongodb::mongos::params::unixsocketprefix`

##### <a name="-mongodb--mongos--pidfilepath"></a>`pidfilepath`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `$mongodb::mongos::params::pidfilepath`

##### <a name="-mongodb--mongos--logpath"></a>`logpath`

Data type: `Optional[Variant[Boolean, Stdlib::Absolutepath]]`



Default value: `$mongodb::mongos::params::logpath`

##### <a name="-mongodb--mongos--fork"></a>`fork`

Data type: `Optional[Boolean]`



Default value: `$mongodb::mongos::params::fork`

##### <a name="-mongodb--mongos--bind_ip"></a>`bind_ip`

Data type: `Optional[Array[Stdlib::IP::Address]]`



Default value: `$mongodb::mongos::params::bind_ip`

##### <a name="-mongodb--mongos--port"></a>`port`

Data type: `Optional[Stdlib::Port]`



Default value: `$mongodb::mongos::params::port`

##### <a name="-mongodb--mongos--restart"></a>`restart`

Data type: `Boolean`



Default value: `$mongodb::mongos::params::restart`

### <a name="mongodb--opsmanager"></a>`mongodb::opsmanager`

This installs Ops Manager

#### Parameters

The following parameters are available in the `mongodb::opsmanager` class:

* [`user`](#-mongodb--opsmanager--user)
* [`group`](#-mongodb--opsmanager--group)
* [`ensure`](#-mongodb--opsmanager--ensure)
* [`package_name`](#-mongodb--opsmanager--package_name)
* [`package_ensure`](#-mongodb--opsmanager--package_ensure)
* [`service_enable`](#-mongodb--opsmanager--service_enable)
* [`service_manage`](#-mongodb--opsmanager--service_manage)
* [`service_name`](#-mongodb--opsmanager--service_name)
* [`download_url`](#-mongodb--opsmanager--download_url)
* [`mongo_uri`](#-mongodb--opsmanager--mongo_uri)
* [`opsmanager_url`](#-mongodb--opsmanager--opsmanager_url)
* [`client_certificate_mode`](#-mongodb--opsmanager--client_certificate_mode)
* [`from_email_addr`](#-mongodb--opsmanager--from_email_addr)
* [`reply_to_email_addr`](#-mongodb--opsmanager--reply_to_email_addr)
* [`admin_email_addr`](#-mongodb--opsmanager--admin_email_addr)
* [`email_dao_class`](#-mongodb--opsmanager--email_dao_class)
* [`mail_transport`](#-mongodb--opsmanager--mail_transport)
* [`smtp_server_hostname`](#-mongodb--opsmanager--smtp_server_hostname)
* [`smtp_server_port`](#-mongodb--opsmanager--smtp_server_port)
* [`ssl`](#-mongodb--opsmanager--ssl)
* [`ignore_ui_setup`](#-mongodb--opsmanager--ignore_ui_setup)
* [`ca_file`](#-mongodb--opsmanager--ca_file)
* [`pem_key_file`](#-mongodb--opsmanager--pem_key_file)
* [`pem_key_password`](#-mongodb--opsmanager--pem_key_password)
* [`user_svc_class`](#-mongodb--opsmanager--user_svc_class)
* [`snapshot_interval`](#-mongodb--opsmanager--snapshot_interval)
* [`snapshot_interval_retention`](#-mongodb--opsmanager--snapshot_interval_retention)
* [`snapshot_daily_retention`](#-mongodb--opsmanager--snapshot_daily_retention)
* [`snapshot_weekly_retention`](#-mongodb--opsmanager--snapshot_weekly_retention)
* [`snapshot_monthly_retention`](#-mongodb--opsmanager--snapshot_monthly_retention)
* [`versions_directory`](#-mongodb--opsmanager--versions_directory)

##### <a name="-mongodb--opsmanager--user"></a>`user`

Data type: `String[1]`

The user that owns the config file

Default value: `'mongodb-mms'`

##### <a name="-mongodb--opsmanager--group"></a>`group`

Data type: `String[1]`

The group that owns the config file

Default value: `'mongodb-mms'`

##### <a name="-mongodb--opsmanager--ensure"></a>`ensure`

Data type: `Enum['running', 'stopped']`



Default value: `'running'`

##### <a name="-mongodb--opsmanager--package_name"></a>`package_name`

Data type: `String[1]`



Default value: `'mongodb-mms'`

##### <a name="-mongodb--opsmanager--package_ensure"></a>`package_ensure`

Data type: `String[1]`



Default value: `'present'`

##### <a name="-mongodb--opsmanager--service_enable"></a>`service_enable`

Data type: `Boolean`



Default value: `true`

##### <a name="-mongodb--opsmanager--service_manage"></a>`service_manage`

Data type: `Boolean`



Default value: `true`

##### <a name="-mongodb--opsmanager--service_name"></a>`service_name`

Data type: `String[1]`



Default value: `'mongodb-mms'`

##### <a name="-mongodb--opsmanager--download_url"></a>`download_url`

Data type: `Stdlib::Httpurl`



Default value: `'https://downloads.mongodb.com/on-prem-mms/rpm/mongodb-mms-4.0.1.50101.20180801T1117Z-1.x86_64.rpm'`

##### <a name="-mongodb--opsmanager--mongo_uri"></a>`mongo_uri`

Data type: `String[1]`



Default value: `'mongodb://127.0.0.1:27017'`

##### <a name="-mongodb--opsmanager--opsmanager_url"></a>`opsmanager_url`

Data type: `Stdlib::Httpurl`

The fully qualified url where opsmanager runs. Must include the port.

Default value: `"http://${facts['networking']['fqdn']}:8080"`

##### <a name="-mongodb--opsmanager--client_certificate_mode"></a>`client_certificate_mode`

Data type: `String[1]`



Default value: `'None'`

##### <a name="-mongodb--opsmanager--from_email_addr"></a>`from_email_addr`

Data type: `String[1]`



Default value: `'from@example.com'`

##### <a name="-mongodb--opsmanager--reply_to_email_addr"></a>`reply_to_email_addr`

Data type: `String[1]`



Default value: `'reply-to@example.com'`

##### <a name="-mongodb--opsmanager--admin_email_addr"></a>`admin_email_addr`

Data type: `String[1]`



Default value: `'admin@example.com'`

##### <a name="-mongodb--opsmanager--email_dao_class"></a>`email_dao_class`

Data type: `String[1]`



Default value: `'com.xgen.svc.core.dao.email.JavaEmailDao'`

##### <a name="-mongodb--opsmanager--mail_transport"></a>`mail_transport`

Data type: `Enum['smtp','smtps']`



Default value: `'smtp'`

##### <a name="-mongodb--opsmanager--smtp_server_hostname"></a>`smtp_server_hostname`

Data type: `Stdlib::Host`



Default value: `'smtp.example.com'`

##### <a name="-mongodb--opsmanager--smtp_server_port"></a>`smtp_server_port`

Data type: `Stdlib::Port`



Default value: `25`

##### <a name="-mongodb--opsmanager--ssl"></a>`ssl`

Data type: `Boolean`



Default value: `false`

##### <a name="-mongodb--opsmanager--ignore_ui_setup"></a>`ignore_ui_setup`

Data type: `Boolean`



Default value: `true`

##### <a name="-mongodb--opsmanager--ca_file"></a>`ca_file`

Data type: `Optional[String[1]]`

Ca file for secure connection to backup agents.

Default value: `undef`

##### <a name="-mongodb--opsmanager--pem_key_file"></a>`pem_key_file`

Data type: `Optional[String[1]]`

Pem key file containing the cert and private key used for secure connections to backup agents.

Default value: `undef`

##### <a name="-mongodb--opsmanager--pem_key_password"></a>`pem_key_password`

Data type: `Optional[String[1]]`

The password to the pem key file.

Default value: `undef`

##### <a name="-mongodb--opsmanager--user_svc_class"></a>`user_svc_class`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--snapshot_interval"></a>`snapshot_interval`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--snapshot_interval_retention"></a>`snapshot_interval_retention`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--snapshot_daily_retention"></a>`snapshot_daily_retention`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--snapshot_weekly_retention"></a>`snapshot_weekly_retention`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--snapshot_monthly_retention"></a>`snapshot_monthly_retention`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--opsmanager--versions_directory"></a>`versions_directory`

Data type: `Optional[Integer]`



Default value: `undef`

### <a name="mongodb--replset"></a>`mongodb::replset`

Wrapper class useful for hiera based deployments

#### Parameters

The following parameters are available in the `mongodb::replset` class:

* [`sets`](#-mongodb--replset--sets)

##### <a name="-mongodb--replset--sets"></a>`sets`

Data type: `Any`



Default value: `undef`

### <a name="mongodb--server"></a>`mongodb::server`

This installs a MongoDB server. See README.md for more details.

#### Parameters

The following parameters are available in the `mongodb::server` class:

* [`tls`](#-mongodb--server--tls)
* [`tls_key`](#-mongodb--server--tls_key)
* [`tls_ca`](#-mongodb--server--tls_ca)
* [`tls_conn_without_cert`](#-mongodb--server--tls_conn_without_cert)
* [`tls_invalid_hostnames`](#-mongodb--server--tls_invalid_hostnames)
* [`tls_mode`](#-mongodb--server--tls_mode)
* [`admin_password_hash`](#-mongodb--server--admin_password_hash)
* [`ensure`](#-mongodb--server--ensure)
* [`user`](#-mongodb--server--user)
* [`group`](#-mongodb--server--group)
* [`config`](#-mongodb--server--config)
* [`dbpath`](#-mongodb--server--dbpath)
* [`dbpath_fix`](#-mongodb--server--dbpath_fix)
* [`pidfilepath`](#-mongodb--server--pidfilepath)
* [`pidfilemode`](#-mongodb--server--pidfilemode)
* [`manage_pidfile`](#-mongodb--server--manage_pidfile)
* [`rcfile`](#-mongodb--server--rcfile)
* [`service_manage`](#-mongodb--server--service_manage)
* [`service_provider`](#-mongodb--server--service_provider)
* [`service_name`](#-mongodb--server--service_name)
* [`service_enable`](#-mongodb--server--service_enable)
* [`service_ensure`](#-mongodb--server--service_ensure)
* [`service_status`](#-mongodb--server--service_status)
* [`package_ensure`](#-mongodb--server--package_ensure)
* [`package_name`](#-mongodb--server--package_name)
* [`logpath`](#-mongodb--server--logpath)
* [`bind_ip`](#-mongodb--server--bind_ip)
* [`ipv6`](#-mongodb--server--ipv6)
* [`logappend`](#-mongodb--server--logappend)
* [`system_logrotate`](#-mongodb--server--system_logrotate)
* [`fork`](#-mongodb--server--fork)
* [`port`](#-mongodb--server--port)
* [`journal`](#-mongodb--server--journal)
* [`nojournal`](#-mongodb--server--nojournal)
* [`smallfiles`](#-mongodb--server--smallfiles)
* [`cpu`](#-mongodb--server--cpu)
* [`auth`](#-mongodb--server--auth)
* [`noauth`](#-mongodb--server--noauth)
* [`verbose`](#-mongodb--server--verbose)
* [`verbositylevel`](#-mongodb--server--verbositylevel)
* [`objcheck`](#-mongodb--server--objcheck)
* [`quota`](#-mongodb--server--quota)
* [`quotafiles`](#-mongodb--server--quotafiles)
* [`diaglog`](#-mongodb--server--diaglog)
* [`directoryperdb`](#-mongodb--server--directoryperdb)
* [`profile`](#-mongodb--server--profile)
* [`maxconns`](#-mongodb--server--maxconns)
* [`oplog_size`](#-mongodb--server--oplog_size)
* [`nohints`](#-mongodb--server--nohints)
* [`nohttpinterface`](#-mongodb--server--nohttpinterface)
* [`noscripting`](#-mongodb--server--noscripting)
* [`notablescan`](#-mongodb--server--notablescan)
* [`noprealloc`](#-mongodb--server--noprealloc)
* [`nssize`](#-mongodb--server--nssize)
* [`mms_token`](#-mongodb--server--mms_token)
* [`mms_name`](#-mongodb--server--mms_name)
* [`mms_interval`](#-mongodb--server--mms_interval)
* [`replset`](#-mongodb--server--replset)
* [`replset_config`](#-mongodb--server--replset_config)
* [`replset_members`](#-mongodb--server--replset_members)
* [`configsvr`](#-mongodb--server--configsvr)
* [`shardsvr`](#-mongodb--server--shardsvr)
* [`rest`](#-mongodb--server--rest)
* [`quiet`](#-mongodb--server--quiet)
* [`slowms`](#-mongodb--server--slowms)
* [`keyfile`](#-mongodb--server--keyfile)
* [`key`](#-mongodb--server--key)
* [`set_parameter`](#-mongodb--server--set_parameter)
* [`syslog`](#-mongodb--server--syslog)
* [`config_content`](#-mongodb--server--config_content)
* [`config_template`](#-mongodb--server--config_template)
* [`config_data`](#-mongodb--server--config_data)
* [`ssl`](#-mongodb--server--ssl)
* [`ssl_key`](#-mongodb--server--ssl_key)
* [`ssl_ca`](#-mongodb--server--ssl_ca)
* [`ssl_weak_cert`](#-mongodb--server--ssl_weak_cert)
* [`ssl_invalid_hostnames`](#-mongodb--server--ssl_invalid_hostnames)
* [`ssl_mode`](#-mongodb--server--ssl_mode)
* [`restart`](#-mongodb--server--restart)
* [`storage_engine`](#-mongodb--server--storage_engine)
* [`create_admin`](#-mongodb--server--create_admin)
* [`admin_username`](#-mongodb--server--admin_username)
* [`admin_password`](#-mongodb--server--admin_password)
* [`admin_auth_mechanism`](#-mongodb--server--admin_auth_mechanism)
* [`admin_update_password`](#-mongodb--server--admin_update_password)
* [`handle_creds`](#-mongodb--server--handle_creds)
* [`store_creds`](#-mongodb--server--store_creds)
* [`admin_roles`](#-mongodb--server--admin_roles)

##### <a name="-mongodb--server--tls"></a>`tls`

Data type: `Boolean`

Ensure tls is enabled.

Default value: `false`

##### <a name="-mongodb--server--tls_key"></a>`tls_key`

Data type: `Optional[Stdlib::Absolutepath]`

Defines the path of the file that contains the TLS/SSL certificate and key.

Default value: `undef`

##### <a name="-mongodb--server--tls_ca"></a>`tls_ca`

Data type: `Optional[Stdlib::Absolutepath]`

Defines the path of the file that contains the certificate chain for verifying client certificates.

Default value: `undef`

##### <a name="-mongodb--server--tls_conn_without_cert"></a>`tls_conn_without_cert`

Data type: `Boolean`

Set to true to bypass client certificate validation for clients that do not present a certificate.

Default value: `false`

##### <a name="-mongodb--server--tls_invalid_hostnames"></a>`tls_invalid_hostnames`

Data type: `Boolean`

Set to true to disable the validation of the hostnames in TLS certificates.

Default value: `false`

##### <a name="-mongodb--server--tls_mode"></a>`tls_mode`

Data type: `Enum['requireTLS', 'preferTLS', 'allowTLS']`

Defines if TLS is used for all network connections. Allowed values are 'requireTLS', 'preferTLS' or 'allowTLS'.

Default value: `'requireTLS'`

##### <a name="-mongodb--server--admin_password_hash"></a>`admin_password_hash`

Data type: `Optional[Variant[String[1], Sensitive[String[1]]]]`

Hashed password. Hex encoded md5 hash of mongodb password.

Default value: `undef`

##### <a name="-mongodb--server--ensure"></a>`ensure`

Data type: `Variant[Boolean, String]`



Default value: `$mongodb::params::ensure`

##### <a name="-mongodb--server--user"></a>`user`

Data type: `String`



Default value: `$mongodb::params::user`

##### <a name="-mongodb--server--group"></a>`group`

Data type: `String`



Default value: `$mongodb::params::group`

##### <a name="-mongodb--server--config"></a>`config`

Data type: `Stdlib::Absolutepath`



Default value: `$mongodb::params::config`

##### <a name="-mongodb--server--dbpath"></a>`dbpath`

Data type: `Stdlib::Absolutepath`



Default value: `$mongodb::params::dbpath`

##### <a name="-mongodb--server--dbpath_fix"></a>`dbpath_fix`

Data type: `Boolean`



Default value: `$mongodb::params::dbpath_fix`

##### <a name="-mongodb--server--pidfilepath"></a>`pidfilepath`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `$mongodb::params::pidfilepath`

##### <a name="-mongodb--server--pidfilemode"></a>`pidfilemode`

Data type: `String`



Default value: `$mongodb::params::pidfilemode`

##### <a name="-mongodb--server--manage_pidfile"></a>`manage_pidfile`

Data type: `Boolean`



Default value: `$mongodb::params::manage_pidfile`

##### <a name="-mongodb--server--rcfile"></a>`rcfile`

Data type: `String`



Default value: `$mongodb::params::rcfile`

##### <a name="-mongodb--server--service_manage"></a>`service_manage`

Data type: `Boolean`



Default value: `$mongodb::params::service_manage`

##### <a name="-mongodb--server--service_provider"></a>`service_provider`

Data type: `Optional[String]`



Default value: `$mongodb::params::service_provider`

##### <a name="-mongodb--server--service_name"></a>`service_name`

Data type: `Optional[String]`



Default value: `$mongodb::params::service_name`

##### <a name="-mongodb--server--service_enable"></a>`service_enable`

Data type: `Boolean`



Default value: `$mongodb::params::service_enable`

##### <a name="-mongodb--server--service_ensure"></a>`service_ensure`

Data type: `Enum['stopped', 'running']`



Default value: `$mongodb::params::service_ensure`

##### <a name="-mongodb--server--service_status"></a>`service_status`

Data type: `Optional[Enum['stopped', 'running']]`



Default value: `$mongodb::params::service_status`

##### <a name="-mongodb--server--package_ensure"></a>`package_ensure`

Data type: `Variant[Boolean, String]`



Default value: `$mongodb::params::package_ensure`

##### <a name="-mongodb--server--package_name"></a>`package_name`

Data type: `String`



Default value: `$mongodb::params::server_package_name`

##### <a name="-mongodb--server--logpath"></a>`logpath`

Data type: `Variant[Boolean, Stdlib::Absolutepath]`



Default value: `$mongodb::params::logpath`

##### <a name="-mongodb--server--bind_ip"></a>`bind_ip`

Data type: `Array[Stdlib::IP::Address]`



Default value: `$mongodb::params::bind_ip`

##### <a name="-mongodb--server--ipv6"></a>`ipv6`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--logappend"></a>`logappend`

Data type: `Boolean`



Default value: `true`

##### <a name="-mongodb--server--system_logrotate"></a>`system_logrotate`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-mongodb--server--fork"></a>`fork`

Data type: `Optional[Boolean]`



Default value: `$mongodb::params::fork`

##### <a name="-mongodb--server--port"></a>`port`

Data type: `Optional[Integer[1, 65535]]`



Default value: `undef`

##### <a name="-mongodb--server--journal"></a>`journal`

Data type: `Optional[Boolean]`



Default value: `$mongodb::params::journal`

##### <a name="-mongodb--server--nojournal"></a>`nojournal`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--smallfiles"></a>`smallfiles`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--cpu"></a>`cpu`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--auth"></a>`auth`

Data type: `Boolean`



Default value: `false`

##### <a name="-mongodb--server--noauth"></a>`noauth`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--verbose"></a>`verbose`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--verbositylevel"></a>`verbositylevel`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-mongodb--server--objcheck"></a>`objcheck`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--quota"></a>`quota`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--quotafiles"></a>`quotafiles`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--server--diaglog"></a>`diaglog`

Data type: `Optional[Integer[0, 7]]`



Default value: `undef`

##### <a name="-mongodb--server--directoryperdb"></a>`directoryperdb`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--profile"></a>`profile`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--maxconns"></a>`maxconns`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--server--oplog_size"></a>`oplog_size`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--server--nohints"></a>`nohints`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--nohttpinterface"></a>`nohttpinterface`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--noscripting"></a>`noscripting`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--notablescan"></a>`notablescan`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--noprealloc"></a>`noprealloc`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--nssize"></a>`nssize`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--server--mms_token"></a>`mms_token`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--mms_name"></a>`mms_name`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--mms_interval"></a>`mms_interval`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--replset"></a>`replset`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-mongodb--server--replset_config"></a>`replset_config`

Data type: `Optional[Hash]`



Default value: `undef`

##### <a name="-mongodb--server--replset_members"></a>`replset_members`

Data type: `Optional[Array]`



Default value: `undef`

##### <a name="-mongodb--server--configsvr"></a>`configsvr`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--shardsvr"></a>`shardsvr`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--rest"></a>`rest`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--quiet"></a>`quiet`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--slowms"></a>`slowms`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-mongodb--server--keyfile"></a>`keyfile`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-mongodb--server--key"></a>`key`

Data type: `Optional[Variant[String[6], Sensitive[String[6]]]]`



Default value: `undef`

##### <a name="-mongodb--server--set_parameter"></a>`set_parameter`

Data type: `Optional[Variant[String[1], Array[String[1]]]]`



Default value: `undef`

##### <a name="-mongodb--server--syslog"></a>`syslog`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--config_content"></a>`config_content`

Data type: `Any`



Default value: `undef`

##### <a name="-mongodb--server--config_template"></a>`config_template`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-mongodb--server--config_data"></a>`config_data`

Data type: `Optional[Hash]`



Default value: `undef`

##### <a name="-mongodb--server--ssl"></a>`ssl`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-mongodb--server--ssl_key"></a>`ssl_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-mongodb--server--ssl_ca"></a>`ssl_ca`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-mongodb--server--ssl_weak_cert"></a>`ssl_weak_cert`

Data type: `Boolean`



Default value: `false`

##### <a name="-mongodb--server--ssl_invalid_hostnames"></a>`ssl_invalid_hostnames`

Data type: `Boolean`



Default value: `false`

##### <a name="-mongodb--server--ssl_mode"></a>`ssl_mode`

Data type: `Enum['requireSSL', 'preferSSL', 'allowSSL']`



Default value: `'requireSSL'`

##### <a name="-mongodb--server--restart"></a>`restart`

Data type: `Boolean`



Default value: `$mongodb::params::restart`

##### <a name="-mongodb--server--storage_engine"></a>`storage_engine`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-mongodb--server--create_admin"></a>`create_admin`

Data type: `Boolean`



Default value: `$mongodb::params::create_admin`

##### <a name="-mongodb--server--admin_username"></a>`admin_username`

Data type: `String`



Default value: `$mongodb::params::admin_username`

##### <a name="-mongodb--server--admin_password"></a>`admin_password`

Data type: `Optional[Variant[String, Sensitive[String]]]`



Default value: `undef`

##### <a name="-mongodb--server--admin_auth_mechanism"></a>`admin_auth_mechanism`

Data type: `Enum['scram_sha_1', 'scram_sha_256']`



Default value: `$mongodb::params::admin_auth_mechanism`

##### <a name="-mongodb--server--admin_update_password"></a>`admin_update_password`

Data type: `Boolean`



Default value: `false`

##### <a name="-mongodb--server--handle_creds"></a>`handle_creds`

Data type: `Boolean`



Default value: `$mongodb::params::handle_creds`

##### <a name="-mongodb--server--store_creds"></a>`store_creds`

Data type: `Boolean`



Default value: `$mongodb::params::store_creds`

##### <a name="-mongodb--server--admin_roles"></a>`admin_roles`

Data type: `Array`



Default value: `$mongodb::params::admin_roles`

### <a name="mongodb--shardsvr"></a>`mongodb::shardsvr`

Wrapper class useful for hiera based deployments

#### Parameters

The following parameters are available in the `mongodb::shardsvr` class:

* [`shards`](#-mongodb--shardsvr--shards)

##### <a name="-mongodb--shardsvr--shards"></a>`shards`

Data type: `Any`



Default value: `undef`

## Defined types

### <a name="mongodb--db"></a>`mongodb::db`

Class for creating mongodb databases and users.

#### Parameters

The following parameters are available in the `mongodb::db` defined type:

* [`user`](#-mongodb--db--user)
* [`auth_mechanism`](#-mongodb--db--auth_mechanism)
* [`db_name`](#-mongodb--db--db_name)
* [`password_hash`](#-mongodb--db--password_hash)
* [`password`](#-mongodb--db--password)
* [`roles`](#-mongodb--db--roles)
* [`tries`](#-mongodb--db--tries)
* [`update_password`](#-mongodb--db--update_password)

##### <a name="-mongodb--db--user"></a>`user`

Data type: `String`

Database username.

##### <a name="-mongodb--db--auth_mechanism"></a>`auth_mechanism`

Data type: `Enum['scram_sha_1', 'scram_sha_256']`

Authentication mechanism. scram_sha_256 password verification is not supported. Defaults to 'scram_sha_1'.

Default value: `'scram_sha_1'`

##### <a name="-mongodb--db--db_name"></a>`db_name`

Data type: `String`

Database name. Defaults to $name.

Default value: `$name`

##### <a name="-mongodb--db--password_hash"></a>`password_hash`

Data type: `Optional[Variant[String[1], Sensitive[String[1]]]]`

Hashed password. Hex encoded md5 hash of "$username:mongo:$password".

Default value: `undef`

##### <a name="-mongodb--db--password"></a>`password`

Data type: `Optional[Variant[String[1], Sensitive[String[1]]]]`

Plain text user password. This is UNSAFE, use 'password_hash' instead.

Default value: `undef`

##### <a name="-mongodb--db--roles"></a>`roles`

Data type: `Array[String]`

Array with user roles. Deaults to ['dbAdmin']

Default value: `['dbAdmin']`

##### <a name="-mongodb--db--tries"></a>`tries`

Data type: `Integer[0]`

The maximum amount of two second tries to wait MongoDB startup. Defaults to 10.

Default value: `10`

##### <a name="-mongodb--db--update_password"></a>`update_password`

Data type: `Boolean`

Force an update of the password when scram_sha_256 is used. Defaults to false.

Default value: `false`

## Resource types

### <a name="mongodb_conn_validator"></a>`mongodb_conn_validator`

Verify that a connection can be successfully established between a node
and the mongodb server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the mongodb
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Properties

The following properties are available in the `mongodb_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

Ensurable property

Default value: `present`

#### Parameters

The following parameters are available in the `mongodb_conn_validator` type.

* [`name`](#-mongodb_conn_validator--name)
* [`port`](#-mongodb_conn_validator--port)
* [`provider`](#-mongodb_conn_validator--provider)
* [`server`](#-mongodb_conn_validator--server)
* [`timeout`](#-mongodb_conn_validator--timeout)

##### <a name="-mongodb_conn_validator--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource. It can also be the connection string to test (ie.
127.0.0.1:27017)

##### <a name="-mongodb_conn_validator--port"></a>`port`

The port that the mongodb server should be listening on.

Default value: `27017`

##### <a name="-mongodb_conn_validator--provider"></a>`provider`

The specific backend to use for this `mongodb_conn_validator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-mongodb_conn_validator--server"></a>`server`

An array containing DNS names or IP addresses of the server where mongodb should be running.

Default value: `127.0.0.1`

##### <a name="-mongodb_conn_validator--timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that puppetdb is not running;
defaults to 60 seconds.

Default value: `60`

### <a name="mongodb_database"></a>`mongodb_database`

Manage MongoDB databases.

#### Properties

The following properties are available in the `mongodb_database` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mongodb_database` type.

* [`name`](#-mongodb_database--name)
* [`provider`](#-mongodb_database--provider)
* [`tries`](#-mongodb_database--tries)

##### <a name="-mongodb_database--name"></a>`name`

Valid values: `%r{^[\w-]+$}`

namevar

The name of the database.

##### <a name="-mongodb_database--provider"></a>`provider`

The specific backend to use for this `mongodb_database` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-mongodb_database--tries"></a>`tries`

Valid values: `%r{^\d+$}`

The maximum amount of two second tries to wait MongoDB startup.

Default value: `10`

### <a name="mongodb_replset"></a>`mongodb_replset`

Manage a MongoDB replicaSet

#### Properties

The following properties are available in the `mongodb_replset` type.

##### `ensure`

Valid values: `present`

Ensurable property

Default value: `present`

##### `members`

The replicaSet members config

##### `settings`

The replicaSet settings config

#### Parameters

The following parameters are available in the `mongodb_replset` type.

* [`arbiter`](#-mongodb_replset--arbiter)
* [`initialize_host`](#-mongodb_replset--initialize_host)
* [`name`](#-mongodb_replset--name)
* [`provider`](#-mongodb_replset--provider)

##### <a name="-mongodb_replset--arbiter"></a>`arbiter`

The replicaSet arbiter

##### <a name="-mongodb_replset--initialize_host"></a>`initialize_host`

Host to use for Replicaset initialization

Default value: `127.0.0.1`

##### <a name="-mongodb_replset--name"></a>`name`

namevar

The name of the replicaSet

##### <a name="-mongodb_replset--provider"></a>`provider`

The specific backend to use for this `mongodb_replset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mongodb_shard"></a>`mongodb_shard`

Manage a MongoDB Shard

#### Properties

The following properties are available in the `mongodb_shard` type.

##### `ensure`

Valid values: `present`

Ensurable property

Default value: `present`

##### `keys`

The sharding keys

##### `member`

The shard member

#### Parameters

The following parameters are available in the `mongodb_shard` type.

* [`name`](#-mongodb_shard--name)
* [`provider`](#-mongodb_shard--provider)

##### <a name="-mongodb_shard--name"></a>`name`

namevar

The name of the shard

##### <a name="-mongodb_shard--provider"></a>`provider`

The specific backend to use for this `mongodb_shard` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mongodb_user"></a>`mongodb_user`

Manage a MongoDB user. This includes management of users password as well as privileges.

#### Properties

The following properties are available in the `mongodb_user` type.

##### `database`

Valid values: `%r{^[\w-]+$}`

The user's target database.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `password`

The plaintext password of the user.

##### `password_hash`

Valid values: `%r{^\w+$}`

The password hash of the user. Use mongodb_password() for creating hash. Only available on MongoDB 3.0 and later. SCRAM-SHA-256 authentication mechanism is not supported.

##### `roles`

Valid values: `%r{^\w+(@\w+)?$}`

The user's roles.

Default value: `['dbAdmin']`

##### `scram_credentials`

The SCRAM-SHA-1 credentials of a user. These are read only and change when password or password_hash changes.

##### `username`

The name of the user.

#### Parameters

The following parameters are available in the `mongodb_user` type.

* [`auth_mechanism`](#-mongodb_user--auth_mechanism)
* [`name`](#-mongodb_user--name)
* [`provider`](#-mongodb_user--provider)
* [`tries`](#-mongodb_user--tries)
* [`update_password`](#-mongodb_user--update_password)

##### <a name="-mongodb_user--auth_mechanism"></a>`auth_mechanism`

Valid values: `scram_sha_256`, `scram_sha_1`

Authentication mechanism. Password verification is not supported with SCRAM-SHA-256.

Default value: `scram_sha_1`

##### <a name="-mongodb_user--name"></a>`name`

namevar

The name of the resource.

##### <a name="-mongodb_user--provider"></a>`provider`

The specific backend to use for this `mongodb_user` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-mongodb_user--tries"></a>`tries`

Valid values: `%r{^\d+$}`

The maximum amount of two second tries to wait MongoDB startup.

Default value: `10`

##### <a name="-mongodb_user--update_password"></a>`update_password`

Update password. Used with SCRAM-SHA-256 because password verification is not supported.

Default value: `false`

## Functions

### <a name="mongodb_password"></a>`mongodb_password`

Type: Ruby 4.x API

Get the mongodb password hash from the clear text password.

#### `mongodb_password(String[1] $username, Variant[String[1], Sensitive[String[1]]] $password, Optional[Boolean] $sensitive)`

Get the mongodb password hash from the clear text password.

Returns: `Variant[String, Sensitive[String]]`

##### `username`

Data type: `String[1]`



##### `password`

Data type: `Variant[String[1], Sensitive[String[1]]]`



##### `sensitive`

Data type: `Optional[Boolean]`



